# papertronics-sdk
This **S**oftware **D**evelopment **K**it aims to make it easy for external services, like [the Beer-O-Meter](https://testmybeer.com/), to interact with the SG Papertronics LAB backend.
This application is **Open Source** for anyone to use to integrate their software with our LAB system. However, proper credentials are required in order to access the system.
To purchase these credentials, please contact j.g.heersink@sgpapertronics.com or contact us via [our website](https://sgpapertronics.com/).

